[![Build status](https://travis-ci.org/kutaslab/fitgrid.svg?branch=master)](https://travis-ci.org/kutaslab/fitgrid)
[![Coverage](https://codecov.io/gh/kutaslab/fitgrid/branch/master/graph/badge.svg)](https://codecov.io/gh/kutaslab/fitgrid)

# fitgrid

Run models on a 2D grid where each cell holds a dataset.

## Demo

Click this button to launch a demo notebook:

[![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gh/kutaslab/fitgrid/master?filepath=notebooks/Demo.ipynb)

## Installation

    conda install -c kutaslab fitgrid

for full support.  Alternatively (with no `lmer` support),

    pip3 install fitgrid

## Documentation

Available [here](https://kutaslab.github.io/fitgrid).
